==> orpheus_ml-1.0.2.1-py3-none-any.whl: orpheus/metrics/constants.py <==
"""Constants for metrics module."""

SCORE_TYPES = {
    "regression": {
        "minimize": [
            "root_mean_squared_error",
            "mean_squared_error",
            "mean_absolute_error",
            "mean_squared_log_error",
            "median_absolute_error",
            "mean_absolute_percentage_error",
            "max_error",
            "mean_poisson_deviance",
            "mean_gamma_deviance",
            "mean_tweedie_deviance",
        ],
        "maximize": [
            "r2_score",
            "explained_variance_score",
            "neg_mean_squared_error",
            "neg_mean_absolute_error",
            "neg_mean_squared_log_error",
            "neg_median_absolute_error",
        ],
    },
    "classification": {
        "maximize": [
            "accuracy_score",
            "average_precision_score",
            "balanced_accuracy_score",
            "f1_score",
            "fbeta_score",
            "jaccard_score",
            "precision_score",
            "recall_score",
            "roc_auc_score",
            "top_k_accuracy_score",
            "adjusted_mutual_info_score",
            "completeness_score",
            "fowlkes_mallows_score",
            "homogeneity_completeness_v_measure",
            "homogeneity_score",
            "mutual_info_score",
            "normalized_mutual_info_score",
            "v_measure_score",
            "silhouette_score",
            "roc_auc_ovr",
            "roc_auc_ovo",
        ],
        "minimize": [
            "hamming_loss",
            "hinge_loss",
            "log_loss",
            "zero_one_loss",
            "brier_score_loss",
            "cohen_kappa_score",
            "matthews_corrcoef",
            "neg_log_loss",
            "neg_brier_score",
        ],
    },
}

==> orpheus_ml-1.2.3-py3-none-any.whl: orpheus/metrics/constants.py <==
"""Constants for metrics module."""

SCORE_TYPES = {
    "regression": {
        "minimize": [
            "mean_squared_error",
            "mean_absolute_error",
            "mean_squared_log_error",
            "median_absolute_error",
            "mean_absolute_percentage_error",
            "root_mean_squared_log_error",
            "max_error",
            "mean_poisson_deviance",
            "mean_gamma_deviance",
            "mean_tweedie_deviance",
            "root_mean_squared_error", 
            "mean_pinball_loss", 
            "d2_tweedie_score",  
            "d2_absolute_error_score", 
            "d2_pinball_score",  
        ],
        "maximize": [
            "r2_score",
            "explained_variance_score",
        ],
    },
    "classification": {
        "maximize": [
            "accuracy_score",
            "average_precision_score",
            "balanced_accuracy_score",
            "f1_score",
            "fbeta_score",
            "jaccard_score",
            "precision_score",
            "recall_score",
            "roc_auc_score",
            "top_k_accuracy_score",
            "adjusted_mutual_info_score",
            "completeness_score",
            "fowlkes_mallows_score",
            "homogeneity_score",
            "mutual_info_score",
            "normalized_mutual_info_score",
            "v_measure_score",
            "adjusted_rand_score",  
            "label_ranking_average_precision_score",  
            "label_ranking_loss", 
        ],
        "minimize": [
            "hamming_loss",
            "hinge_loss",
            "log_loss",
            "zero_one_loss",
            "brier_score_loss",
            "cohen_kappa_score",
            "matthews_corrcoef",
        ],
    },
}
